function [xi1, xi2, wxi, family] = padpts(n, varargin)
% [xi1, xi2, wxi, family] = padpts(n, vertex)
%
% Builds Padua points of n-th degree.
%
% n      = the degree of the Padua points. Must be a positive integer.
% vertex = a string describing where the vertex points are. Possible
%          values are: 'T' (top), 'B' (bottom), 'L' (left), 'R' (right).
%
% xi1    = the x values of Padua points.
% xi2    = the y values of Padua points.
% wxi    = the weights associated to each Padua point.
% family = an integer containing the Padua point family. Needed by
%          other functions.

if (~isPosInteger(n))
  error('n must be a positive integer.')
end

if (nargin == 1)
  vertex = 'T';
elseif (nargin == 2)
  vertex = varargin{1};
else
  error('Wrong parameters number.');
end

if (strcmp(vertex, 'T'))
  if (mod(n,2) == 0)
    [xi1, xi2, wxi] = padpts3(n);
    family = 'Padua3';
  else
    [xi1, xi2, wxi] = padpts4(n);
    family = 'Padua4';
  end
elseif (strcmp(vertex, 'B'))
  if (mod(n, 2) == 0)
    [xi1, xi2, wxi] = padpts1(n);
    family = 'Padua1';
  else
    [xi1, xi2, wxi] = padpts2(n);
    family = 'Padua2';
  end
elseif (strcmp(vertex, 'L'))
  if (mod(n, 2) == 0)
    [xi1, xi2, wxi] = padpts2(n);
    family = 'Padua2';
  else
    [xi1, xi2, wxi] = padpts1(n);
    family = 'Padua1';
  end
elseif (strcmp(vertex, 'R'))
  if (mod(n, 2) == 0)
    [xi1, xi2, wxi] = padpts4(n);
    family = 'Padua4';
  else
    [xi1, xi2, wxi] = padpts3(n);
    family = 'Padua3';
  end
else
  error('Unknown vertex.');
end
